changecase

package module
v1.4.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 20, 2025 License: MIT Imports: 4 Imported by: 0

README

changecase

  • convert command line arguments to upper, lower or title case
  • return the combined length of all command-line arguments
  • check for string equality with optional case-insensitive matching
  • outputs all content except a trailing newline, mimicking Perl's chomp functionality

Synopsis

These programs convert all command line arguments to their respective case and are also Unicode aware.

Provided programs:

  • lower
  • upper
  • titlecase
  • len
  • eq
  • chomp

Usage

lower [arguments]
upper [arguments]
titlecase [arguments]
len [arguments]
eq [arguments]
chomp
(consider surrounding command-line arguments in double-quotes to preserve spacing)

Installation

  • macOS: brew update; brew install jftuga/tap/changecase
  • Binaries for Linux, macOS and Windows are provided in the releases section.

Documentation

Index

Constants

const PgmUrl string = "https://github.com/jftuga/changecase"
const PgmVersion string = "1.4.0"

Variables

This section is empty.

Functions

func Lower

func Lower(args []string) string

Lower - return a lower case string

func TitleCase

func TitleCase(args []string) string

TitleCase - return a title case string

func Upper

func Upper(args []string) string

Upper - return an upper case string

func Usage

func Usage(pgmName string)

Usage - output when no cmd-line args are given

Types

This section is empty.

Directories

Path Synopsis
cmd
chomp command
eq command
eq is a command-line utility for string comparison
eq is a command-line utility for string comparison
len command
lower command
titlecase command
upper command

Jump to