changecase

package module
v1.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 24, 2023 License: MIT Imports: 4 Imported by: 0

README

changecase

  • convert command line arguments to upper, lower or title case
  • return the combined length of all command-line arguments

Synopsis

These programs convert all command line arguments to their respective case and are also Unicode aware.

Provided programs:

  • lower
  • upper
  • titlecase
  • len

Usage

lower [arguments]
upper [arguments]
titlecase [arguments]
len [arguments]
(consider surrounding command-line arguments in double-quotes to preserve spacing)

Installation

  • macOS: brew update; brew install jftuga/tap/changecase
  • Binaries for Linux, macOS and Windows are provided in the releases section.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Lower

func Lower(args []string) string

Lower - return a lower case string

func TitleCase

func TitleCase(args []string) string

TitleCase - return a title case string

func Upper

func Upper(args []string) string

Upper - return an upper case string

func Usage

func Usage(pgmName string)

Usage - output when no cmd-line args are given

Types

This section is empty.

Directories

Path Synopsis
cmd
len command
lower command
titlecase command
upper command

Jump to